==> AxolotlClient-3.1.6%2B1.21.1-sources.jar: io/github/axolotlclient/modules/mcci/MccIslandLocation.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.mcci;

import java.util.concurrent.CompletableFuture;

import io.github.axolotlclient.util.Util;

public class MccIslandLocation {
	private static CompletableFuture<MccIslandLocationData> consumer;

	public static CompletableFuture<MccIslandLocationData> get() {
		Util.sendChatMessage("/whereami");
		consumer = new CompletableFuture<>();
		return consumer;
	}

	public static boolean waitingForResponse(String message) {
		MccIslandLocationData data = null;
		boolean consume = consumer != null && (data = MccIslandLocationData.parse(message)) != null;
		if (consume) {
			consumer.complete(data);
			consumer = null;
		}
		return consume;
	}
}

==> AxolotlClient-3.1.7%2B1.21.11-sources.jar: io/github/axolotlclient/modules/mcci/MccIslandLocation.java <==
/*
 * Copyright © 2024 moehreag <moehreag@gmail.com> & Contributors
 *
 * This file is part of AxolotlClient.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * For more information, see the LICENSE file.
 */

package io.github.axolotlclient.modules.mcci;

import java.util.concurrent.CompletableFuture;

import io.github.axolotlclient.util.Util;

public class MccIslandLocation {
	private static CompletableFuture<MccIslandLocationData> consumer;

	public static CompletableFuture<MccIslandLocationData> get() {
		Util.sendChatMessage("/whereami");
		consumer = new CompletableFuture<>();
		return consumer;
	}

	static boolean waitingForResponse(String message) {
		MccIslandLocationData data = null;
		boolean consume = consumer != null && (data = MccIslandLocationData.parse(message)) != null;
		if (consume) {
			consumer.complete(data);
			consumer = null;
		}
		return consume;
	}
}
